function [RHO] = density_ch4(press,temp)

% DENSITY_CH4 -  calculates the density of CH4 based on an EOS
%      The toolbox script EOS_CH4 is called.
%
%      Usage: rho = density_ch4(p,T)
%
%      Input parameters (scalars or vectors): 
%          p        - pressure [MPa]     (0.012 < p < 1000) 
%          T        - temperature [degC] (-183< T < 347)
%
%      Output parameter:
%          rho      - density of CH4 [kg/m^3]
%
%      References:
%      Setzmann & Wagner (1991) J. Phys. Chem. Ref. Data 20, 1061-1155.
%
% ------------------------------------------------------------------
%   written by: Elke Kossel, Matthias Haeckel (August 2009)
%               GEOMAR, Kiel, Germany
%   Disclaimer:
%   This software is provided "as is" without warranty of any kind.
% ------------------------------------------------------------------


%------------------------------------------------------------------------
% Check number of input parameters
%------------------------------------------------------------------------

if nargin < 2
     warning('DENSITY_CH4:Input','DENSITY_CH4: Missing input parameter! Please provide p and T!')
else
    %call external function eos_seawater to calculate density
     RHO = eos_ch4(press,temp);
 end
 
