function [RHO] = density_co2(press,temp)

% DENSITY_CO2 -  calculates the density of CO2 based on an EOS
%      The toolbox script EOS_CO2 is called.
%
%      Usage: rho = density_co2(p,T)
%
%      Input parameters (scalars or vectors): 
%          p        - pressure [MPa]     (0 < p < 800) 
%          T        - temperature [degC] (-57 (0)< T < 827)
%
%      Output parameter:
%           rho     - density of CO2 [kg/m^3]
%
%      References:
%      Span & Wagner (1996) J.Phys.Chem.Ref.Data 25(6), 1509-1596.
%
% ------------------------------------------------------------------
%   written by: Elke Kossel, Matthias Haeckel (August 2009)
%               IFM-GEOMAR, Kiel, Germany
%   Disclaimer:
%   This software is provided "as is" without warranty of any kind.
% ------------------------------------------------------------------


%------------------------------------------------------------------------
% Check number of input parameters
%------------------------------------------------------------------------

if nargin < 2
     warning('DENSITY_CO2:Input','DENSITY_CO2: Missing input parameter! Please provide p and T!')
else
    %call external function eos_seawater to calculate density
     RHO = eos_co2(press,temp);
 end
 
